<?php
/**
 * Theme customizer functions & hooks
 *
 * @package fad
 * @since 3.0.0
 */

/**
 * Enqueue scripts to add custom functionality for customizer controls.
 *
 * @return void
 */
function fad_customizer_scripts() {
	wp_enqueue_script( 'fad-customizer-controls', get_template_directory_uri() . '/assets/js/customizer-controls.js', array( 'jquery' ), '1.0.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'fad_customizer_scripts' );

/**
 * [fad_sanitize_checkbox description].
 *
 * @param  bool $value [description].
 * @return bool        [description].
 */
function fad_sanitize_checkbox( $value ) {
	$result = filter_var( $value, FILTER_VALIDATE_BOOLEAN );
	if ( ! $result ) {
		return false;
	}
	return $result;
}

/**
 * Returns either light or dark contrast text color depending on the background color value.
 *
 * @param  string $bg_color         The background color hex color value.
 * @param  string $dark_text_color  The dark text color hex color value.
 * @param  string $light_text_color The light text color hex color value.
 * @return string                   The contrast text hex color value.
 */
function fad_get_contrast_text_color( $bg_color, $dark_text_color = '#000000', $light_text_color = '#FFFFFF' ) {
	$bg_color_rgb = sscanf( $bg_color, '#%02x%02x%02x' );
	$light_color_rgb = sscanf( $light_text_color, '#%02x%02x%02x' );

	$bg_color_luminosity =
		0.2126 * pow( $bg_color_rgb[0] / 255, 2.2 ) +
		0.7152 * pow( $bg_color_rgb[1] / 255, 2.2 ) +
		0.0722 * pow( $bg_color_rgb[2] / 255, 2.2 );

	$light_color_luminosity =
		0.2126 * pow( $light_color_rgb[0] / 255, 2.2 ) +
		0.7152 * pow( $light_color_rgb[1] / 255, 2.2 ) +
		0.0722 * pow( $light_color_rgb[2] / 255, 2.2 );

	$luminosity_difference = ( $light_color_luminosity + 0.05 ) / ( $bg_color_luminosity + 0.05 );
	if ( $bg_color_luminosity > $light_color_luminosity ) {
		$luminosity_difference = ( $bg_color_luminosity + 0.05 ) / ( $light_color_luminosity + 0.05 );
	}

	if ( 5 < $luminosity_difference ) {
		return $light_text_color;
	}

	return $dark_text_color;
}

/**
 * Include customizer color options.
 */
require_once get_template_directory() . '/inc/customizer/options/colors.php';

/**
 * Include customizer layout options.
 */
require_once get_template_directory() . '/inc/customizer/options/layout.php';

/**
 * Include customizer typography options.
 */
require_once get_template_directory() . '/inc/customizer/options/typography.php';

/**
 * Include customizer homepage options.
 */
require_once get_template_directory() . '/inc/customizer/options/homepage.php';
