<?php
/**
 * Theme hooks
 *
 * @package fad
 * @since 3.0.0
 */

/**
 * Add preconnect for Google Fonts.
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function fad_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'fad-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'fad_resource_hints', 10, 2 );

/**
 * Modifies the default excerpt length.
 *
 * @param  int $length The default excerpt length.
 * @return int         The modified excerpt length.
 */
function fad_excerpt_length( $length ) {
	if ( ! is_admin() ) {
		$length = get_theme_mod( 'fad_excerpt_length', 30 );
	}

	return $length;
}
add_filter( 'excerpt_length', 'fad_excerpt_length' );

/**
 * Modifies the default excerpt more markup.
 *
 * @param  string $more The default excerpt more markup.
 * @return string       The modified excerpt more markup.
 */
function fad_excerpt_more( $more ) {
	if ( ! is_admin() ) {
		$more = esc_html__( '&hellip;', 'fad' ) .
			sprintf( '<p><a href="%s" class="more-link">', esc_url( get_permalink() ) ) .
				get_theme_mod( 'fad_excerpt_more', esc_html__( 'Read more', 'fad' ) ) .
				'<span class="screen-reader-text">' .
					esc_html__( ' of ', 'fad' ) . esc_html( get_the_title() ) .
				'</span>' .
			'</a></p>';
	}

	return $more;
}
add_filter( 'excerpt_more', 'fad_excerpt_more' );

/**
 * Modifies the default body classes as per the theme's design.
 *
 * @param  array $classes The default body classes.
 * @return array          The modified body classes.
 */
function fad_body_class( $classes ) {
	if ( ! is_active_sidebar( 'sidebar' ) ) {
		$classes[] = 'sidebar-layout-none';
	}

	return $classes;
}
add_filter( 'body_class', 'fad_body_class' );

/**
 * Checks if the show post excerpt option is enabled.
 */
function fad_show_excerpt() {
	if ( ! is_admin() ) {
		$show_post_excerpt = get_theme_mod( 'fad_show_post_excerpt', 'default' );
		if ( '1' == $show_post_excerpt ) {
			the_excerpt();
		}
	}

	return false;
}
